@@ -1,8 +1,8 @@
 from .return_class import AbstractApiClass
-from .refresh_schedule import RefreshSchedule
 import time
-from .model_version import ModelVersion
 from .model_location import ModelLocation
+from .refresh_schedule import RefreshSchedule
+from .model_version import ModelVersion
 
 
 class Model(AbstractApiClass):
@@ -45,9 +45,6 @@ class Model(AbstractApiClass):
     def rename(self, name):
         return self.client.rename_model(self.model_id, name)
 
-    def update_training_config(self, training_config):
-        return self.client.update_model_training_config(self.model_id, training_config)
-
     def update_python(self, function_source_code=None, train_function_name=None, predict_function_name=None, training_input_tables=[]):
         return self.client.update_python_model(self.model_id, function_source_code, train_function_name, predict_function_name, training_input_tables)
 
